@@ -6,12 +6,13 @@ our @EXPORT = qw<
     pre p div span hr 
     style
     script
-    html head body title import_css import_js meta http_equiv meta_name meta_content
+    html head body title import_css import_js meta meta_ http_equiv meta_name meta_content
     h1 h2 h3 h4 h5 h6
     table cell row th table_heads table_rows caption
     tspan rowspan colspan
     form label
     input input_form input_text input_pwd
+    input_button
     input_tag input_check input_checked input_keep_check input_radio
     submit input_submit
     select_tag option input_select 
@@ -25,8 +26,14 @@ our @EXPORT = qw<
     quote blockquote
     textarea
     fieldset
+    br br_
 >;
 
+sub br     ($) { empty_tag br   => @_ }
+sub br_        { empty_tag br   => +{@_} }
+sub meta   ($) { empty_tag meta => @_ }
+sub meta_      { empty_tag meta => +{@_} }
+
 sub fieldset    (&) { tag fieldset   => @_ }
 sub style          { "<style>", @_, "</style>" }
 sub caption    (&) { tag caption   => @_ }
@@ -99,6 +106,8 @@ sub input_tag {
     @_ and $form{value} = shift;
     tag input => 0, +{ %form, @_ }
 }
+sub input_button      { input_tag button => @_ }
+sub button      { tag button => @_ }
 sub input_pwd     { input_tag password => @_ }
 sub input_text    { input_tag text     => @_ }
 sub input_keep_check {
